==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QLidReading.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Holds readings from the Lid sensor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qlidreading.html">QLidReading</a></p>
 */
public class QLidReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLidReading.class);
    

    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> backLidChanged = new Signal1<>();

    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> frontLidChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLidReading() {
        this((io.qt.core.QObject)null);
    }
    
    public QLidReading(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLidReading instance, io.qt.core.QObject parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #backLidClosed()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getBackLidClosed() {
        return backLidClosed();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlidreading.html#backLidClosed-prop">QLidReading::backLidClosed()const</a></p>
     */
    @QtPropertyReader(name="backLidClosed")
    @QtUninvokable
    public final boolean backLidClosed(){
        return backLidClosed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean backLidClosed_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #frontLidClosed()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getFrontLidClosed() {
        return frontLidClosed();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlidreading.html#frontLidClosed-prop">QLidReading::frontLidClosed()const</a></p>
     */
    @QtPropertyReader(name="frontLidClosed")
    @QtUninvokable
    public final boolean frontLidClosed(){
        return frontLidClosed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean frontLidClosed_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlidreading.html#setBackLidClosed">QLidReading::setBackLidClosed(bool)</a></p>
     */
    @QtUninvokable
    public final void setBackLidClosed(boolean closed){
        setBackLidClosed_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), closed);
    }
    
    @QtUninvokable
    private native void setBackLidClosed_native_bool(long __this__nativeId, boolean closed);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlidreading.html#setFrontLidClosed">QLidReading::setFrontLidClosed(bool)</a></p>
     */
    @QtUninvokable
    public final void setFrontLidClosed(boolean closed){
        setFrontLidClosed_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), closed);
    }
    
    @QtUninvokable
    private native void setFrontLidClosed_native_bool(long __this__nativeId, boolean closed);
    
    @QtUninvokable
    protected void copyValuesFrom(io.qt.sensors.@Nullable QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QLidReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QLidReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QLidReading instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.2.1-sources.jar: io/qt/sensors/QLidReading.java <==
package io.qt.sensors;


/**
 * <p>Java wrapper for Qt class QLidReading</p>
 */
public class QLidReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLidReading.class);
    

    public final Signal1<@io.qt.QtPrimitiveType Boolean> backLidChanged = new Signal1<>();

    public final Signal1<@io.qt.QtPrimitiveType Boolean> frontLidChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLidReading(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLidReading() {
        this((io.qt.core.QObject)null);
    }
    
    public QLidReading(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLidReading instance, io.qt.core.QObject parent);
    
    @io.qt.QtPropertyReader(name="backLidClosed")
    @io.qt.QtUninvokable
    public final boolean backLidClosed(){
        return backLidClosed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean backLidClosed_native_constfct(long __this__nativeId);
    
    @io.qt.QtPropertyReader(name="frontLidClosed")
    @io.qt.QtUninvokable
    public final boolean frontLidClosed(){
        return frontLidClosed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean frontLidClosed_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setBackLidClosed(boolean closed){
        setBackLidClosed_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), closed);
    }
    
    @io.qt.QtUninvokable
    private native void setBackLidClosed_native_bool(long __this__nativeId, boolean closed);
    
    @io.qt.QtUninvokable
    public final void setFrontLidClosed(boolean closed){
        setFrontLidClosed_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), closed);
    }
    
    @io.qt.QtUninvokable
    private native void setFrontLidClosed_native_bool(long __this__nativeId, boolean closed);
    
    @io.qt.QtUninvokable
    protected void copyValuesFrom(io.qt.sensors.QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLidReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLidReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLidReading instance, QDeclarativeConstructor constructor);
    
}
